==> wccp-pro-2.0.6.1.zip: wccp-pro/admin_help.php <==
<strong>Fast FAQ</strong>
<div class="col">
<div id="accordion">
  <div class="card"><!-- Question Start -->
    <div class="card-header" id="headingOne">
      <h5 class="mb-0">
        <span class="btn btn-link" data-toggle="collapse" data-target="#collapseOne" aria-expanded="true" aria-controls="collapseOne">
          How to exclude admin from protection
        </span>
      </h5>
    </div>

    <div id="collapseOne" class="collapse show" aria-labelledby="headingOne" data-parent="#accordion">
      <div class="card-body">
        <ul>
			<li>Please open the plugin exclusion tab and then go to (exclude by user type) option</li>
			<li>Its called exclusion by user type</li>
			<li>Choose the user types you want to exclude and save the settings</li>
			<li>Clear any cache and check</li>
			<li>Thank you</li>
		</ul>
      </div>
    </div>
  </div><!-- Question End -->
  <div class="card"><!-- Question Start -->
    <div class="card-header" id="headingTwo">
      <h5 class="mb-0">
        <span class="btn btn-link collapsed" data-toggle="collapse" data-target="#collapseTwo" aria-expanded="false" aria-controls="collapseTwo">
          How to exclude images from watermarking?
        </span>
      </h5>
    </div>
    <div id="collapseTwo" class="collapse" aria-labelledby="headingTwo" data-parent="#accordion">
      <div class="card-body">
         <div class="entry-content" style="box-sizing: border-box; outline: none !important; margin-bottom: 75px; color: rgb(100, 100, 100); font-family: Arial, Helvetica, sans-serif; font-size: 15px; font-style: normal; font-variant-ligatures: normal; font-variant-caps: normal; font-weight: 400; letter-spacing: normal; orphans: 2; text-align: start; text-indent: 0px; text-transform: none; white-space: normal; widows: 2; word-spacing: 0px; -webkit-text-stroke-width: 0px; background-color: rgb(255, 255, 255); text-decoration-style: initial; text-decoration-color: initial;">
	<p>
	<strong>
	The first way, exclude by post URL:</strong></p>
	<p>
	By using this way, all images inside that URL will not be watermarked</p>
	<p>
	<strong>
	Note</strong>: There is no need to put the full URL, you can put any part of 
	it and it will work fine</p>
	<p>
	<span style="box-sizing: border-box; outline: none !important; text-decoration: underline;">
	Example</span>: mysite.com/post-name OR www.mysite.com/post-name</p>
	<p>
	If you use any URL ends with /* then all URLs start with that URL will be 
	excluded (this called&nbsp;<strong><span style="box-sizing: border-box; outline: none !important; text-decoration: underline;">bulk 
	exclusion</span></strong>)</p>
	<p>
	<span style="box-sizing: border-box; outline: none !important; text-decoration: underline;">
	Example</span>: mysite.com/cart/*</p>
	<p>
	<img class="aligncenter size-full wp-image-15542" src="https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-34-40-PM.png" alt="" width="754" height="167" srcset="https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-34-40-PM.png 754w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-34-40-PM-300x66.png 300w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-34-40-PM-645x143.png 645w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-34-40-PM-560x124.png 560w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-34-40-PM-750x166.png 750w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-34-40-PM-400x89.png 400w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-34-40-PM-228x50.png 228w" sizes="(max-width: 754px) 100vw, 754px" style="box-sizing: border-box; outline: none !important; border: 0px; vertical-align: middle; transition: background 0.3s ease 0s, border-color 0.2s ease 0s, color 0.3s ease 0s; text-align: center; clear: both; display: block; margin: 7px auto; max-width: 100%; height: auto;"></p>
	<p>
	<strong>
	The second way, exclude registered images sizes:</strong></p>
	<p>
	This way is great, it tells the plugin to not watermark any image with a 
	chosen size, this is a very effective way to reduce the use of server 
	resources and improve the speed of the page.</p>
	<p>
	We recommend choosing small sizes to be out of watermarking, for a simple 
	reason, No one wants to steal a small image!</p>
	<p>
	This feature depends on image names generated by WordPress when you uploaded 
	it, not real image sizes, if the size of the image is not a part of its 
	name, it will be watermarked</p>
	<p>
	<span style="box-sizing: border-box; outline: none !important; text-decoration: underline;">
	For example</span>: if you have an image with size 1000X1000 but its name is 
	image_150x150 then it will be treated as 150×150 image because of its name</p>
	<p>
	<img class="aligncenter size-full wp-image-15543" src="https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-41-17-PM.png" alt="" width="757" height="315" srcset="https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-41-17-PM.png 757w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-41-17-PM-300x125.png 300w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-41-17-PM-645x268.png 645w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-41-17-PM-560x233.png 560w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-41-17-PM-750x312.png 750w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-41-17-PM-400x166.png 400w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-41-17-PM-228x95.png 228w" sizes="(max-width: 757px) 100vw, 757px" style="box-sizing: border-box; outline: none !important; border: 0px; vertical-align: middle; transition: background 0.3s ease 0s, border-color 0.2s ease 0s, color 0.3s ease 0s; text-align: center; clear: both; display: block; margin: 7px auto; max-width: 100%; height: auto;"></p>
	<p>
	<strong>
	The third way, Exclude images by name &amp; size (manually):</strong></p>
	<p>
	Simply, Enter any image name to be excluded from watermarking 
	(Comma-separated)</p>
	<p>
	Write excluded images names or some parts of names with comma separated</p>
	<p>
	<span style="box-sizing: border-box; outline: none !important; text-decoration: underline;">
	Note</span>: The image name is enough to exclude it without its full URL</p>
	<p>
	<img class="aligncenter size-full wp-image-15544" src="https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-47-37-PM.png" alt="" width="783" height="173" srcset="https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-47-37-PM.png 783w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-47-37-PM-300x66.png 300w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-47-37-PM-768x170.png 768w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-47-37-PM-645x143.png 645w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-47-37-PM-560x124.png 560w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-47-37-PM-750x166.png 750w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-47-37-PM-400x88.png 400w, https://www.wp-buy.com/wp-content/uploads/2020/05/5-29-2020-10-47-37-PM-228x50.png 228w" sizes="(max-width: 783px) 100vw, 783px" style="box-sizing: border-box; outline: none !important; border: 0px; vertical-align: middle; transition: background 0.3s ease 0s, border-color 0.2s ease 0s, color 0.3s ease 0s; text-align: center; clear: both; display: block; margin: 7px auto; max-width: 100%; height: auto;"></p>
	<p>
	That’s all, Thank you
	</div>
      </div>
    </div>
  </div><!-- Question End -->
  <div class="card"><!-- Question Start -->
    <div class="card-header" id="headingThree">
      <h5 class="mb-0">
        <span class="btn btn-link collapsed" data-toggle="collapse" data-target="#collapseThree" aria-expanded="false" aria-controls="collapseThree">
          Smart protection, What this feature can do?
        </span>
      </h5>
    </div>
    <div id="collapseThree" class="collapse" aria-labelledby="headingThree" data-parent="#accordion">
      <div class="card-body">
		<p>This feature is a very smart trick to put a transparent image over your images if the user can PayPass right click protection layer and he does right-click over your image to save it</p>
        <p>he will save the transparent image instead of saving the original one because of its located above the original image</p>
		<p><img src="https://www.wp-buy.com/wp-content/uploads/2019/08/pure-white-background-021aa40c-228x126.png"></p>
		<p>That’s it, Thank you</p>
      </div>
    </div>
  </div><!-- Question End -->
  <div class="card"><!-- Question Start -->
    <div class="card-header" id="heading4">
      <h5 class="mb-0">
        <span class="btn btn-link collapsed" data-toggle="collapse" data-target="#collapse4" aria-expanded="false" aria-controls="collapse4">
          Need more help?
        </span>
      </h5>
    </div>
    <div id="collapse4" class="collapse" aria-labelledby="heading4" data-parent="#accordion">
      <div class="card-body">
		<p>We would love to hear from you! Please write any question you want and we will get in touch with you shortly</p>
        <p>Have your own issue? Support Center will help you</p>
		<p><a class=" current " href="https://www.wp-buy.com/category/plugins-support/copy-protection-plugin-support/">Support Center</a></p>
		<p>Thank you</p>
      </div>
    </div>
  </div><!-- Question End -->
</div>
</div>

<style>
span.btn.btn-link {
    font-size: 11px;
}

.card-header {
    padding: 7px !important;
	cursor: pointer;
}
.card {
padding: 0px !important;
}
</style>

==> wccp-pro_v16.9.zip: wccp-pro/admin_help.php <==
<?php if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly ?>
<strong>Fast FAQ</strong>
<div class="col">
<div id="accordion">
  <div class="card"><!-- Question Start -->
    <div class="card-header" id="headingOne">
      <h5 class="mb-0">
        <span class="btn btn-link" data-toggle="collapse" data-target="#collapseOne" aria-expanded="true" aria-controls="collapseOne">
          How to exclude admin from protection
        </span>
      </h5>
    </div>

    <div id="collapseOne" class="collapse show" aria-labelledby="headingOne" data-parent="#accordion">
      <div class="card-body">
        <ul>
			<li>Please open the plugin exclusion tab and then go to (exclude by user type) option</li>
			<li>Its called exclusion by user type</li>
			<li>Choose the user types you want to exclude and save the settings</li>
			<li>Clear any cache and check</li>
			<li>Thank you</li>
		</ul>
      </div>
    </div>
  </div><!-- Question End -->
  <div class="card"><!-- Question Start -->
    <div class="card-header" id="headingTwo">
      <h5 class="mb-0">
        <span class="btn btn-link collapsed" data-toggle="collapse" data-target="#collapseTwo" aria-expanded="false" aria-controls="collapseTwo">
          How to exclude images from watermarking?
        </span>
      </h5>
    </div>
    <div id="collapseTwo" class="collapse" aria-labelledby="headingTwo" data-parent="#accordion">
      <div class="card-body">
         <div class="entry-content" style="box-sizing: border-box; outline: none !important; margin-bottom: 75px; color: rgb(100, 100, 100); font-family: Arial, Helvetica, sans-serif; font-size: 15px; font-style: normal; font-variant-ligatures: normal; font-variant-caps: normal; font-weight: 400; letter-spacing: normal; orphans: 2; text-align: start; text-indent: 0px; text-transform: none; white-space: normal; widows: 2; word-spacing: 0px; -webkit-text-stroke-width: 0px; background-color: rgb(255, 255, 255); text-decoration-style: initial; text-decoration-color: initial;">
	<p>
	<strong>
	The first way, exclude by post URL:</strong></p>
	<p>
	By using this way, all images inside that URL will not be watermarked</p>
	<p>
	<strong>
	Note</strong>: There is no need to put the full URL, you can put any part of 
	it and it will work fine</p>
	<p>
	<span style="box-sizing: border-box; outline: none !important; text-decoration: underline;">
	Example</span>: mysite.com/post-name OR www.mysite.com/post-name</p>
	<p>
	If you use any URL ends with /* then all URLs start with that URL will be 
	excluded (this called&nbsp;<strong><span style="box-sizing: border-box; outline: none !important; text-decoration: underline;">bulk 
	exclusion</span></strong>)</p>
	<p>
	<span style="box-sizing: border-box; outline: none !important; text-decoration: underline;">
	Example</span>: mysite.com/cart/*</p>
	<p><?php $pluginsurl = plugins_url( '', __FILE__ ); ?>
	<img class="aligncenter size-full wp-image-15542" src="<?php echo $pluginsurl; ?>/images/help-shots/5-29-2020-10-34-40-PM.png" alt="" width="754" height="167" style="box-sizing: border-box; outline: none !important; border: 0px; vertical-align: middle; transition: background 0.3s ease 0s, border-color 0.2s ease 0s, color 0.3s ease 0s; text-align: center; clear: both; display: block; margin: 7px auto; max-width: 100%; height: auto;"></p>
	<p>
	<strong>
	The second way, exclude registered images sizes:</strong></p>
	<p>
	This way is great, it tells the plugin to not watermark any image with a 
	chosen size, this is a very effective way to reduce the use of server 
	resources and improve the speed of the page.</p>
	<p>
	We recommend choosing small sizes to be out of watermarking, for a simple 
	reason, No one wants to steal a small image!</p>
	<p>
	This feature depends on image names generated by WordPress when you uploaded 
	it, not real image sizes, if the size of the image is not a part of its 
	name, it will be watermarked</p>
	<p>
	<span style="box-sizing: border-box; outline: none !important; text-decoration: underline;">
	For example</span>: if you have an image with size 1000X1000 but its name is 
	image_150x150 then it will be treated as 150×150 image because of its name</p>
	<p>
	<img class="aligncenter size-full wp-image-15543" src="<?php echo $pluginsurl; ?>/images/help-shots/5-29-2020-10-41-17-PM.png" alt="" width="757" height="315" style="box-sizing: border-box; outline: none !important; border: 0px; vertical-align: middle; transition: background 0.3s ease 0s, border-color 0.2s ease 0s, color 0.3s ease 0s; text-align: center; clear: both; display: block; margin: 7px auto; max-width: 100%; height: auto;"></p>
	<p>
	<strong>
	The third way, Exclude images by name &amp; size (manually):</strong></p>
	<p>
	Simply, Enter any image name to be excluded from watermarking 
	(Comma-separated)</p>
	<p>
	Write excluded images names or some parts of names with comma separated</p>
	<p>
	<span style="box-sizing: border-box; outline: none !important; text-decoration: underline;">
	Note</span>: The image name is enough to exclude it without its full URL</p>
	<p>
	<img class="aligncenter size-full wp-image-15544" src="<?php echo $pluginsurl; ?>/images/help-shots/5-29-2020-10-47-37-PM.png" alt="" width="783" height="173" style="box-sizing: border-box; outline: none !important; border: 0px; vertical-align: middle; transition: background 0.3s ease 0s, border-color 0.2s ease 0s, color 0.3s ease 0s; text-align: center; clear: both; display: block; margin: 7px auto; max-width: 100%; height: auto;"></p>
	<p>
	That’s all, Thank you
	</div>
      </div>
    </div>
  </div><!-- Question End -->
  <div class="card"><!-- Question Start -->
    <div class="card-header" id="headingThree">
      <h5 class="mb-0">
        <span class="btn btn-link collapsed" data-toggle="collapse" data-target="#collapseThree" aria-expanded="false" aria-controls="collapseThree">
          Smart protection, What this feature can do?
        </span>
      </h5>
    </div>
    <div id="collapseThree" class="collapse" aria-labelledby="headingThree" data-parent="#accordion">
      <div class="card-body">
		<p>This feature is a very smart trick to put a transparent image over your images if the user can PayPass right click protection layer and he does right-click over your image to save it</p>
        <p>he will save the transparent image instead of saving the original one because of its located above the original image</p>
		<p><img src="<?php echo $pluginsurl; ?>/images/help-shots/pure-white-background-021aa40c-228x126.png"></p>
		<p>That’s it, Thank you</p>
      </div>
    </div>
  </div><!-- Question End -->
  <div class="card"><!-- Question Start -->
    <div class="card-header" id="heading4">
      <h5 class="mb-0">
        <span class="btn btn-link collapsed" data-toggle="collapse" data-target="#collapse4" aria-expanded="false" aria-controls="collapse4">
          Need more help?
        </span>
      </h5>
    </div>
    <div id="collapse4" class="collapse" aria-labelledby="heading4" data-parent="#accordion">
      <div class="card-body">
		<p>We would love to hear from you! Please write any question you want and we will get in touch with you shortly</p>
        <p>Have your own issue? Support Center will help you</p>
		<p><a class=" current " href="https://www.wp-buy.com/category/plugins-support/copy-protection-plugin-support/">Support Center</a></p>
		<p>Thank you</p>
      </div>
    </div>
  </div><!-- Question End -->
</div>
</div>

<style>
span.btn.btn-link {
    font-size: 11px;
}

.card-header {
    padding: 7px !important;
	cursor: pointer;
}
.card {
padding: 0px !important;
}
</style>
